import type { AnySchema } from "yup";
declare type ValidationFn<ValueType, ParsedType> = (value: ValueType) => {
    error?: undefined;
    parsed: ParsedType;
} | {
    error: Error | string;
    parsed?: undefined;
};
declare type CreateFieldArgs<ValueType, ParsedType = string, YupSchema extends AnySchema<any, any, ParsedType> = AnySchema<any, any, ParsedType>> = {
    id: string;
    initialValue: ValueType;
    initialError?: undefined | string;
    form: {
        actions: {
            add(field: any): any;
            submit(): any;
        };
    };
} & ({
    validate?: ValidationFn<ValueType, ParsedType>;
    validationSchema?: undefined;
} | {
    validate?: undefined;
    validationSchema?: YupSchema;
});
export declare function createField<ValueType = string, ParsedType = string>({ id, initialValue, initialError, form, ...validationProps }: CreateFieldArgs<ValueType, ParsedType>): Field<ValueType, ParsedType>;
export interface Field<ValueType = string, ParsedType = string> {
    state: {
        id: string;
        errorOverride: undefined | string;
        value: ValueType;
        isFocused: boolean;
        wasEverFocused: boolean;
        wasEverBlurred: boolean;
    };
    computed: {
        readonly parsed: ParsedType | undefined;
        readonly isDirty: boolean;
        readonly error: undefined | string;
        readonly ifWasEverFocusedThenError: undefined | string;
        readonly ifWasEverBlurredThenError: undefined | string;
    };
    actions: {
        onFocus(): void;
        onChange(value: ValueType | undefined): void;
        onBlur(): void;
        setError(value: string | undefined): void;
    };
}
export {};
